# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.workflow_tasks_api import WorkflowTasksApi  # noqa: E501
from collibra_core.rest import ApiException


class TestWorkflowTasksApi(unittest.TestCase):
    """WorkflowTasksApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.workflow_tasks_api.WorkflowTasksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_workflow_task(self):
        """Test case for cancel_workflow_task

        Cancel workflow task.  # noqa: E501
        """
        pass

    def test_complete_workflow_tasks(self):
        """Test case for complete_workflow_tasks

        Complete workflow tasks.  # noqa: E501
        """
        pass

    def test_find_workflow_tasks(self):
        """Test case for find_workflow_tasks

        Find workflow tasks.  # noqa: E501
        """
        pass

    def test_get_task_form_data(self):
        """Test case for get_task_form_data

        Get task form data.  # noqa: E501
        """
        pass

    def test_get_workflow_task(self):
        """Test case for get_workflow_task

        Get workflow task.  # noqa: E501
        """
        pass

    def test_reassign_task(self):
        """Test case for reassign_task

        Reassign task.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class ChangeAssignmentRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status_ids': 'list[str]',
        'characteristic_types': 'list[CharacteristicTypeAssignmentReference]',
        'articulation_rules': 'list[ArticulationRuleRequest]',
        'validation_rule_ids': 'list[str]',
        'data_quality_rule_ids': 'list[str]',
        'domain_type_ids': 'list[str]',
        'default_status_id': 'str',
        'scope_id': 'str'
    }

    attribute_map = {
        'status_ids': 'statusIds',
        'characteristic_types': 'characteristicTypes',
        'articulation_rules': 'articulationRules',
        'validation_rule_ids': 'validationRuleIds',
        'data_quality_rule_ids': 'dataQualityRuleIds',
        'domain_type_ids': 'domainTypeIds',
        'default_status_id': 'defaultStatusId',
        'scope_id': 'scopeId'
    }

    def __init__(self, status_ids=None, characteristic_types=None, articulation_rules=None, validation_rule_ids=None, data_quality_rule_ids=None, domain_type_ids=None, default_status_id=None, scope_id=None, local_vars_configuration=None):  # noqa: E501
        """ChangeAssignmentRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status_ids = None
        self._characteristic_types = None
        self._articulation_rules = None
        self._validation_rule_ids = None
        self._data_quality_rule_ids = None
        self._domain_type_ids = None
        self._default_status_id = None
        self._scope_id = None
        self.discriminator = None

        if status_ids is not None:
            self.status_ids = status_ids
        if characteristic_types is not None:
            self.characteristic_types = characteristic_types
        if articulation_rules is not None:
            self.articulation_rules = articulation_rules
        if validation_rule_ids is not None:
            self.validation_rule_ids = validation_rule_ids
        if data_quality_rule_ids is not None:
            self.data_quality_rule_ids = data_quality_rule_ids
        if domain_type_ids is not None:
            self.domain_type_ids = domain_type_ids
        if default_status_id is not None:
            self.default_status_id = default_status_id
        if scope_id is not None:
            self.scope_id = scope_id

    @property
    def status_ids(self):
        """Gets the status_ids of this ChangeAssignmentRequest.  # noqa: E501

        The list of IDs of the statuses  # noqa: E501

        :return: The status_ids of this ChangeAssignmentRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._status_ids

    @status_ids.setter
    def status_ids(self, status_ids):
        """Sets the status_ids of this ChangeAssignmentRequest.

        The list of IDs of the statuses  # noqa: E501

        :param status_ids: The status_ids of this ChangeAssignmentRequest.  # noqa: E501
        :type: list[str]
        """

        self._status_ids = status_ids

    @property
    def characteristic_types(self):
        """Gets the characteristic_types of this ChangeAssignmentRequest.  # noqa: E501

        A list of references to characteristic types corresponding to the assignment.  When adding a 'relationTypeDirection' for a CharacteristicTypeAssignmentReference, all characteristicTypes that reference a RelationType must have the direction set.  # noqa: E501

        :return: The characteristic_types of this ChangeAssignmentRequest.  # noqa: E501
        :rtype: list[CharacteristicTypeAssignmentReference]
        """
        return self._characteristic_types

    @characteristic_types.setter
    def characteristic_types(self, characteristic_types):
        """Sets the characteristic_types of this ChangeAssignmentRequest.

        A list of references to characteristic types corresponding to the assignment.  When adding a 'relationTypeDirection' for a CharacteristicTypeAssignmentReference, all characteristicTypes that reference a RelationType must have the direction set.  # noqa: E501

        :param characteristic_types: The characteristic_types of this ChangeAssignmentRequest.  # noqa: E501
        :type: list[CharacteristicTypeAssignmentReference]
        """

        self._characteristic_types = characteristic_types

    @property
    def articulation_rules(self):
        """Gets the articulation_rules of this ChangeAssignmentRequest.  # noqa: E501

        The articulation rule definitions  # noqa: E501

        :return: The articulation_rules of this ChangeAssignmentRequest.  # noqa: E501
        :rtype: list[ArticulationRuleRequest]
        """
        return self._articulation_rules

    @articulation_rules.setter
    def articulation_rules(self, articulation_rules):
        """Sets the articulation_rules of this ChangeAssignmentRequest.

        The articulation rule definitions  # noqa: E501

        :param articulation_rules: The articulation_rules of this ChangeAssignmentRequest.  # noqa: E501
        :type: list[ArticulationRuleRequest]
        """

        self._articulation_rules = articulation_rules

    @property
    def validation_rule_ids(self):
        """Gets the validation_rule_ids of this ChangeAssignmentRequest.  # noqa: E501

        The list of IDs of the validation rules  # noqa: E501

        :return: The validation_rule_ids of this ChangeAssignmentRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._validation_rule_ids

    @validation_rule_ids.setter
    def validation_rule_ids(self, validation_rule_ids):
        """Sets the validation_rule_ids of this ChangeAssignmentRequest.

        The list of IDs of the validation rules  # noqa: E501

        :param validation_rule_ids: The validation_rule_ids of this ChangeAssignmentRequest.  # noqa: E501
        :type: list[str]
        """

        self._validation_rule_ids = validation_rule_ids

    @property
    def data_quality_rule_ids(self):
        """Gets the data_quality_rule_ids of this ChangeAssignmentRequest.  # noqa: E501

        The list of IDs of the data quality rules  # noqa: E501

        :return: The data_quality_rule_ids of this ChangeAssignmentRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._data_quality_rule_ids

    @data_quality_rule_ids.setter
    def data_quality_rule_ids(self, data_quality_rule_ids):
        """Sets the data_quality_rule_ids of this ChangeAssignmentRequest.

        The list of IDs of the data quality rules  # noqa: E501

        :param data_quality_rule_ids: The data_quality_rule_ids of this ChangeAssignmentRequest.  # noqa: E501
        :type: list[str]
        """

        self._data_quality_rule_ids = data_quality_rule_ids

    @property
    def domain_type_ids(self):
        """Gets the domain_type_ids of this ChangeAssignmentRequest.  # noqa: E501

        The list of IDs of the domain types  # noqa: E501

        :return: The domain_type_ids of this ChangeAssignmentRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._domain_type_ids

    @domain_type_ids.setter
    def domain_type_ids(self, domain_type_ids):
        """Sets the domain_type_ids of this ChangeAssignmentRequest.

        The list of IDs of the domain types  # noqa: E501

        :param domain_type_ids: The domain_type_ids of this ChangeAssignmentRequest.  # noqa: E501
        :type: list[str]
        """

        self._domain_type_ids = domain_type_ids

    @property
    def default_status_id(self):
        """Gets the default_status_id of this ChangeAssignmentRequest.  # noqa: E501

        The ID of the default status for the asset type  # noqa: E501

        :return: The default_status_id of this ChangeAssignmentRequest.  # noqa: E501
        :rtype: str
        """
        return self._default_status_id

    @default_status_id.setter
    def default_status_id(self, default_status_id):
        """Sets the default_status_id of this ChangeAssignmentRequest.

        The ID of the default status for the asset type  # noqa: E501

        :param default_status_id: The default_status_id of this ChangeAssignmentRequest.  # noqa: E501
        :type: str
        """

        self._default_status_id = default_status_id

    @property
    def scope_id(self):
        """Gets the scope_id of this ChangeAssignmentRequest.  # noqa: E501

        The ID of the scope the assignment corresponds to. The scopeId will be removed in the future.  # noqa: E501

        :return: The scope_id of this ChangeAssignmentRequest.  # noqa: E501
        :rtype: str
        """
        return self._scope_id

    @scope_id.setter
    def scope_id(self, scope_id):
        """Sets the scope_id of this ChangeAssignmentRequest.

        The ID of the scope the assignment corresponds to. The scopeId will be removed in the future.  # noqa: E501

        :param scope_id: The scope_id of this ChangeAssignmentRequest.  # noqa: E501
        :type: str
        """

        self._scope_id = scope_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeAssignmentRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChangeAssignmentRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class InlineObject(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'file': 'file',
        'file_name': 'str',
        'resource_type': 'str',
        'resource_id': 'str'
    }

    attribute_map = {
        'file': 'file',
        'file_name': 'fileName',
        'resource_type': 'resourceType',
        'resource_id': 'resourceId'
    }

    def __init__(self, file=None, file_name=None, resource_type=None, resource_id=None, local_vars_configuration=None):  # noqa: E501
        """InlineObject - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._file = None
        self._file_name = None
        self._resource_type = None
        self._resource_id = None
        self.discriminator = None

        if file is not None:
            self.file = file
        if file_name is not None:
            self.file_name = file_name
        if resource_type is not None:
            self.resource_type = resource_type
        if resource_id is not None:
            self.resource_id = resource_id

    @property
    def file(self):
        """Gets the file of this InlineObject.  # noqa: E501

        the file - attachment content  # noqa: E501

        :return: The file of this InlineObject.  # noqa: E501
        :rtype: file
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this InlineObject.

        the file - attachment content  # noqa: E501

        :param file: The file of this InlineObject.  # noqa: E501
        :type: file
        """

        self._file = file

    @property
    def file_name(self):
        """Gets the file_name of this InlineObject.  # noqa: E501

        the display name of the file of this attachment  # noqa: E501

        :return: The file_name of this InlineObject.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this InlineObject.

        the display name of the file of this attachment  # noqa: E501

        :param file_name: The file_name of this InlineObject.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def resource_type(self):
        """Gets the resource_type of this InlineObject.  # noqa: E501

        the type of the resource the attachment should refer to. An attachment can be added on those resource types: User, Community, Domain, Asset, Role, ValidationRule, Workflow.  # noqa: E501

        :return: The resource_type of this InlineObject.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this InlineObject.

        the type of the resource the attachment should refer to. An attachment can be added on those resource types: User, Community, Domain, Asset, Role, ValidationRule, Workflow.  # noqa: E501

        :param resource_type: The resource_type of this InlineObject.  # noqa: E501
        :type: str
        """
        allowed_values = ["View", "Asset", "Community", "Domain", "AssetType", "DomainType", "Status", "User", "ClassificationMatch", "UserGroup", "Attribute", "StringAttribute", "ScriptAttribute", "BooleanAttribute", "DateAttribute", "NumericAttribute", "SingleValueListAttribute", "MultiValueListAttribute", "Comment", "Attachment", "Responsibility", "Workflow", "Job", "Relation", "RelationType", "ComplexRelation", "ComplexRelationType", "ArticulationRule", "Assignment", "Scope", "RelationTrace", "ValidationRule", "DataQualityRule", "DataQualityMetric", "Address", "InstantMessagingAccount", "Email", "PhoneNumber", "Website", "Activity", "FormProperty", "WorkflowTask", "ActivityChange", "WorkflowInstance", "Role", "AttributeType", "BooleanAttributeType", "DateAttributeType", "DateTimeAttributeType", "MultiValueListAttributeType", "NumericAttributeType", "ScriptAttributeType", "SingleValueListAttributeType", "StringAttributeType", "ViewSharingRule", "ViewAssignmentRule", "JdbcDriverFile", "JdbcDriver", "JdbcIngestionProperties", "CsvIngestionProperties", "ExcelIngestionProperties", "ConnectionStringParameter", "AssignedCharacteristicType", "Notification", "Tag", "ComplexRelationLegType", "ComplexRelationAttributeType", "ComplexRelationLeg", "BaseDataType", "AdvancedDataType", "DiagramPicture", "DiagramPictureSharingRule", "DiagramPictureAssignmentRule", "Rating", "Classification", "PhysicalDataConnector", "Context"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and resource_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_type, allowed_values)
            )

        self._resource_type = resource_type

    @property
    def resource_id(self):
        """Gets the resource_id of this InlineObject.  # noqa: E501

        the id of the resource the attachment should refer to  # noqa: E501

        :return: The resource_id of this InlineObject.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this InlineObject.

        the id of the resource the attachment should refer to  # noqa: E501

        :param resource_id: The resource_id of this InlineObject.  # noqa: E501
        :type: str
        """

        self._resource_id = resource_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineObject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineObject):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class TaskFormData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'form_key': 'str',
        'form_properties': 'list[FormProperty]',
        'task_id': 'str',
        'contains_activity_stream': 'bool',
        'subtitle': 'str'
    }

    attribute_map = {
        'form_key': 'formKey',
        'form_properties': 'formProperties',
        'task_id': 'taskId',
        'contains_activity_stream': 'containsActivityStream',
        'subtitle': 'subtitle'
    }

    def __init__(self, form_key=None, form_properties=None, task_id=None, contains_activity_stream=None, subtitle=None, local_vars_configuration=None):  # noqa: E501
        """TaskFormData - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._form_key = None
        self._form_properties = None
        self._task_id = None
        self._contains_activity_stream = None
        self._subtitle = None
        self.discriminator = None

        if form_key is not None:
            self.form_key = form_key
        if form_properties is not None:
            self.form_properties = form_properties
        if task_id is not None:
            self.task_id = task_id
        if contains_activity_stream is not None:
            self.contains_activity_stream = contains_activity_stream
        if subtitle is not None:
            self.subtitle = subtitle

    @property
    def form_key(self):
        """Gets the form_key of this TaskFormData.  # noqa: E501

        The form key.  # noqa: E501

        :return: The form_key of this TaskFormData.  # noqa: E501
        :rtype: str
        """
        return self._form_key

    @form_key.setter
    def form_key(self, form_key):
        """Sets the form_key of this TaskFormData.

        The form key.  # noqa: E501

        :param form_key: The form_key of this TaskFormData.  # noqa: E501
        :type: str
        """

        self._form_key = form_key

    @property
    def form_properties(self):
        """Gets the form_properties of this TaskFormData.  # noqa: E501

        The list of form properties.  # noqa: E501

        :return: The form_properties of this TaskFormData.  # noqa: E501
        :rtype: list[FormProperty]
        """
        return self._form_properties

    @form_properties.setter
    def form_properties(self, form_properties):
        """Sets the form_properties of this TaskFormData.

        The list of form properties.  # noqa: E501

        :param form_properties: The form_properties of this TaskFormData.  # noqa: E501
        :type: list[FormProperty]
        """

        self._form_properties = form_properties

    @property
    def task_id(self):
        """Gets the task_id of this TaskFormData.  # noqa: E501

        The <code>id</code> of the task.  # noqa: E501

        :return: The task_id of this TaskFormData.  # noqa: E501
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this TaskFormData.

        The <code>id</code> of the task.  # noqa: E501

        :param task_id: The task_id of this TaskFormData.  # noqa: E501
        :type: str
        """

        self._task_id = task_id

    @property
    def contains_activity_stream(self):
        """Gets the contains_activity_stream of this TaskFormData.  # noqa: E501

        Whether the task form contains a activity stream.  # noqa: E501

        :return: The contains_activity_stream of this TaskFormData.  # noqa: E501
        :rtype: bool
        """
        return self._contains_activity_stream

    @contains_activity_stream.setter
    def contains_activity_stream(self, contains_activity_stream):
        """Sets the contains_activity_stream of this TaskFormData.

        Whether the task form contains a activity stream.  # noqa: E501

        :param contains_activity_stream: The contains_activity_stream of this TaskFormData.  # noqa: E501
        :type: bool
        """

        self._contains_activity_stream = contains_activity_stream

    @property
    def subtitle(self):
        """Gets the subtitle of this TaskFormData.  # noqa: E501

        The subtitle of the task if any.  # noqa: E501

        :return: The subtitle of this TaskFormData.  # noqa: E501
        :rtype: str
        """
        return self._subtitle

    @subtitle.setter
    def subtitle(self, subtitle):
        """Sets the subtitle of this TaskFormData.

        The subtitle of the task if any.  # noqa: E501

        :param subtitle: The subtitle of this TaskFormData.  # noqa: E501
        :type: str
        """

        self._subtitle = subtitle

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskFormData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TaskFormData):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.relations_api import RelationsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestRelationsApi(unittest.TestCase):
    """RelationsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.relations_api.RelationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_relation(self):
        """Test case for add_relation

        Adds a new relation.  # noqa: E501
        """
        pass

    def test_add_relations(self):
        """Test case for add_relations

        Adds multiple relations in one go.  # noqa: E501
        """
        pass

    def test_change_relation(self):
        """Test case for change_relation

        Changes the relation with the information that is present in the request.  # noqa: E501
        """
        pass

    def test_change_relations(self):
        """Test case for change_relations

        Changes multiple relations.  # noqa: E501
        """
        pass

    def test_find_relations(self):
        """Test case for find_relations

        Returns relations matching the given search criteria.  # noqa: E501
        """
        pass

    def test_get_relation(self):
        """Test case for get_relation

        Returns a relation identified by given id.  # noqa: E501
        """
        pass

    def test_remove_relation(self):
        """Test case for remove_relation

        Removes a relation identified by given id.  # noqa: E501
        """
        pass

    def test_remove_relations(self):
        """Test case for remove_relations

        Removes multiple relations.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ResponsibilitiesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_responsibilities(self, **kwargs):  # noqa: E501
        """Adds multiple responsibilities in one go.  # noqa: E501

        Adds multiple responsibilities in one go. Assigns the given users to the resources with the given roles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_responsibilities(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddResponsibilityRequest] add_responsibility_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ResponsibilityImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_responsibilities_with_http_info(**kwargs)  # noqa: E501

    def add_responsibilities_with_http_info(self, **kwargs):  # noqa: E501
        """Adds multiple responsibilities in one go.  # noqa: E501

        Adds multiple responsibilities in one go. Assigns the given users to the resources with the given roles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_responsibilities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddResponsibilityRequest] add_responsibility_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ResponsibilityImpl], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_responsibility_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_responsibilities" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_responsibility_request' in local_var_params:
            body_params = local_var_params['add_responsibility_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/responsibilities/bulk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ResponsibilityImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_responsibility(self, **kwargs):  # noqa: E501
        """Adds a new responsibility.  # noqa: E501

        Adds new responsibility. Assigns given user to resource with given role.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_responsibility(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddResponsibilityRequest add_responsibility_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ResponsibilityImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_responsibility_with_http_info(**kwargs)  # noqa: E501

    def add_responsibility_with_http_info(self, **kwargs):  # noqa: E501
        """Adds a new responsibility.  # noqa: E501

        Adds new responsibility. Assigns given user to resource with given role.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_responsibility_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddResponsibilityRequest add_responsibility_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ResponsibilityImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_responsibility_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_responsibility" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_responsibility_request' in local_var_params:
            body_params = local_var_params['add_responsibility_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/responsibilities', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponsibilityImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_responsibilities(self, **kwargs):  # noqa: E501
        """Finds responsibilities.  # noqa: E501

        Returns responsibilities matching the given search criteria.  Only parameters that are specified in this request and have not <code>null</code> values are used for filtering.  All other parameters are ignored.  The returned responsibilities satisfy all constraints that are specified in this search criteria.  By default a result containing 1000 responsibilities is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_responsibilities(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param list[str] resource_ids: The list of IDs of the resources for which the responsibilities should be found.
        :param list[str] owner_ids: The list of IDs of the owners for which the responsibilities should be found.
        :param list[str] role_ids: The list of IDs of the roles for which the responsibilities should be found.
        :param bool include_inherited: Whether inherited responsibilities should be included in the search results.
        :param bool global_only: Whether only global responsibilities should be searched.
        :param str sort_field: The field that should be used as reference for sorting.
        :param str sort_order: The order of sorting.
        :param str type: Indicates which type of responsibilities should be searched for. Usage is mutually exclusive with the deprecated globalOnly flag.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PagedResponseResponsibility
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_responsibilities_with_http_info(**kwargs)  # noqa: E501

    def find_responsibilities_with_http_info(self, **kwargs):  # noqa: E501
        """Finds responsibilities.  # noqa: E501

        Returns responsibilities matching the given search criteria.  Only parameters that are specified in this request and have not <code>null</code> values are used for filtering.  All other parameters are ignored.  The returned responsibilities satisfy all constraints that are specified in this search criteria.  By default a result containing 1000 responsibilities is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_responsibilities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param list[str] resource_ids: The list of IDs of the resources for which the responsibilities should be found.
        :param list[str] owner_ids: The list of IDs of the owners for which the responsibilities should be found.
        :param list[str] role_ids: The list of IDs of the roles for which the responsibilities should be found.
        :param bool include_inherited: Whether inherited responsibilities should be included in the search results.
        :param bool global_only: Whether only global responsibilities should be searched.
        :param str sort_field: The field that should be used as reference for sorting.
        :param str sort_order: The order of sorting.
        :param str type: Indicates which type of responsibilities should be searched for. Usage is mutually exclusive with the deprecated globalOnly flag.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PagedResponseResponsibility, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'offset',
            'limit',
            'count_limit',
            'resource_ids',
            'owner_ids',
            'role_ids',
            'include_inherited',
            'global_only',
            'sort_field',
            'sort_order',
            'type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_responsibilities" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'count_limit' in local_var_params and local_var_params['count_limit'] is not None:  # noqa: E501
            query_params.append(('countLimit', local_var_params['count_limit']))  # noqa: E501
        if 'resource_ids' in local_var_params and local_var_params['resource_ids'] is not None:  # noqa: E501
            query_params.append(('resourceIds', local_var_params['resource_ids']))  # noqa: E501
            collection_formats['resourceIds'] = 'multi'  # noqa: E501
        if 'owner_ids' in local_var_params and local_var_params['owner_ids'] is not None:  # noqa: E501
            query_params.append(('ownerIds', local_var_params['owner_ids']))  # noqa: E501
            collection_formats['ownerIds'] = 'multi'  # noqa: E501
        if 'role_ids' in local_var_params and local_var_params['role_ids'] is not None:  # noqa: E501
            query_params.append(('roleIds', local_var_params['role_ids']))  # noqa: E501
            collection_formats['roleIds'] = 'multi'  # noqa: E501
        if 'include_inherited' in local_var_params and local_var_params['include_inherited'] is not None:  # noqa: E501
            query_params.append(('includeInherited', local_var_params['include_inherited']))  # noqa: E501
        if 'global_only' in local_var_params and local_var_params['global_only'] is not None:  # noqa: E501
            query_params.append(('globalOnly', local_var_params['global_only']))  # noqa: E501
        if 'sort_field' in local_var_params and local_var_params['sort_field'] is not None:  # noqa: E501
            query_params.append(('sortField', local_var_params['sort_field']))  # noqa: E501
        if 'sort_order' in local_var_params and local_var_params['sort_order'] is not None:  # noqa: E501
            query_params.append(('sortOrder', local_var_params['sort_order']))  # noqa: E501
        if 'type' in local_var_params and local_var_params['type'] is not None:  # noqa: E501
            query_params.append(('type', local_var_params['type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/responsibilities', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResponseResponsibility',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_responsibility(self, responsibility_id, **kwargs):  # noqa: E501
        """Returns the responsibility identified by the given id.  # noqa: E501

        Returns the responsibility identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_responsibility(responsibility_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str responsibility_id: The unique identifier of the responsibility. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ResponsibilityImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_responsibility_with_http_info(responsibility_id, **kwargs)  # noqa: E501

    def get_responsibility_with_http_info(self, responsibility_id, **kwargs):  # noqa: E501
        """Returns the responsibility identified by the given id.  # noqa: E501

        Returns the responsibility identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_responsibility_with_http_info(responsibility_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str responsibility_id: The unique identifier of the responsibility. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ResponsibilityImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'responsibility_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_responsibility" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'responsibility_id' is set
        if self.api_client.client_side_validation and ('responsibility_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['responsibility_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `responsibility_id` when calling `get_responsibility`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'responsibility_id' in local_var_params:
            path_params['responsibilityId'] = local_var_params['responsibility_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/responsibilities/{responsibilityId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResponsibilityImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_responsibilities(self, **kwargs):  # noqa: E501
        """Removes multiple responsibilities in one go.  # noqa: E501

        Removes multiple responsibilities in one go identified by given ids.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_responsibilities(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: The unique identifiers of the responsibilities.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_responsibilities_with_http_info(**kwargs)  # noqa: E501

    def remove_responsibilities_with_http_info(self, **kwargs):  # noqa: E501
        """Removes multiple responsibilities in one go.  # noqa: E501

        Removes multiple responsibilities in one go identified by given ids.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_responsibilities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: The unique identifiers of the responsibilities.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_responsibilities" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/responsibilities/bulk', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_responsibility(self, responsibility_id, **kwargs):  # noqa: E501
        """Removes the responsibility identified by the given id.  # noqa: E501

        Removes the responsibility identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_responsibility(responsibility_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str responsibility_id: The unique identifier of the responsibility. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_responsibility_with_http_info(responsibility_id, **kwargs)  # noqa: E501

    def remove_responsibility_with_http_info(self, responsibility_id, **kwargs):  # noqa: E501
        """Removes the responsibility identified by the given id.  # noqa: E501

        Removes the responsibility identified by the given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_responsibility_with_http_info(responsibility_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str responsibility_id: The unique identifier of the responsibility. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'responsibility_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_responsibility" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'responsibility_id' is set
        if self.api_client.client_side_validation and ('responsibility_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['responsibility_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `responsibility_id` when calling `remove_responsibility`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'responsibility_id' in local_var_params:
            path_params['responsibilityId'] = local_var_params['responsibility_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/responsibilities/{responsibilityId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class RelationsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_relation(self, **kwargs):  # noqa: E501
        """Adds a new relation.  # noqa: E501

        Adds a new relation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_relation(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddRelationRequest add_relation_request: The properties of the relation to be added
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RelationImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_relation_with_http_info(**kwargs)  # noqa: E501

    def add_relation_with_http_info(self, **kwargs):  # noqa: E501
        """Adds a new relation.  # noqa: E501

        Adds a new relation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_relation_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddRelationRequest add_relation_request: The properties of the relation to be added
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RelationImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_relation_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_relation" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_relation_request' in local_var_params:
            body_params = local_var_params['add_relation_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RelationImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_relations(self, **kwargs):  # noqa: E501
        """Adds multiple relations in one go.  # noqa: E501

        Adds multiple relations in one gos.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_relations(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddRelationRequest] add_relation_request: List of the properties of the relations to be added.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[RelationImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_relations_with_http_info(**kwargs)  # noqa: E501

    def add_relations_with_http_info(self, **kwargs):  # noqa: E501
        """Adds multiple relations in one go.  # noqa: E501

        Adds multiple relations in one gos.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_relations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddRelationRequest] add_relation_request: List of the properties of the relations to be added.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[RelationImpl], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_relation_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_relations" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_relation_request' in local_var_params:
            body_params = local_var_params['add_relation_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relations/bulk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RelationImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_relation(self, relation_id, **kwargs):  # noqa: E501
        """Changes the relation with the information that is present in the request.  # noqa: E501

        Changes the relation with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_relation(relation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str relation_id: The ID of the relation to be changed. (required)
        :param ChangeRelationRequest change_relation_request: The properties of the relation to be changed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RelationImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_relation_with_http_info(relation_id, **kwargs)  # noqa: E501

    def change_relation_with_http_info(self, relation_id, **kwargs):  # noqa: E501
        """Changes the relation with the information that is present in the request.  # noqa: E501

        Changes the relation with the information that is present in the request. Only properties that are specified in this request and have not <code>null</code> values are updated. All other properties are ignored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_relation_with_http_info(relation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str relation_id: The ID of the relation to be changed. (required)
        :param ChangeRelationRequest change_relation_request: The properties of the relation to be changed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RelationImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'relation_id',
            'change_relation_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_relation" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'relation_id' is set
        if self.api_client.client_side_validation and ('relation_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['relation_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `relation_id` when calling `change_relation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'relation_id' in local_var_params:
            path_params['relationId'] = local_var_params['relation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_relation_request' in local_var_params:
            body_params = local_var_params['change_relation_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relations/{relationId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RelationImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_relations(self, **kwargs):  # noqa: E501
        """Changes multiple relations.  # noqa: E501

        Changes multiple relations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_relations(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeRelationRequest] change_relation_request: The list of properties of the relations to be changed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[RelationImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_relations_with_http_info(**kwargs)  # noqa: E501

    def change_relations_with_http_info(self, **kwargs):  # noqa: E501
        """Changes multiple relations.  # noqa: E501

        Changes multiple relations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_relations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ChangeRelationRequest] change_relation_request: The list of properties of the relations to be changed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[RelationImpl], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'change_relation_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_relations" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_relation_request' in local_var_params:
            body_params = local_var_params['change_relation_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relations/bulk', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RelationImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_relations(self, **kwargs):  # noqa: E501
        """Returns relations matching the given search criteria.  # noqa: E501

        Returns relations matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned relations satisfy all constraints that are specified in this search criteria. By default a result containing 1000 relations is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_relations(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>. Cursor should be preferred over offset for better performance and stable results. It is forbidden to use both in the same request.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped. For cursor pagination this parameter is ignored and count is skipped.
        :param str cursor: Cursor for current page of results. To retrieve first page with cursor pagination you need to pass this parameter with empty value. For next pages the value must be taken from response (<code>nextCursor</code> property).
        :param str relation_type_id: The ID of the type of relations to search for.
        :param str source_id: The ID of the source of relations to search for.
        :param str target_id: The ID of the target of relations to search for.
        :param str source_target_logical_operator: The logical operator determining how to combine the source and target criteria: AND or OR.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RelationPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_relations_with_http_info(**kwargs)  # noqa: E501

    def find_relations_with_http_info(self, **kwargs):  # noqa: E501
        """Returns relations matching the given search criteria.  # noqa: E501

        Returns relations matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned relations satisfy all constraints that are specified in this search criteria. By default a result containing 1000 relations is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_relations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>. Cursor should be preferred over offset for better performance and stable results. It is forbidden to use both in the same request.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped. For cursor pagination this parameter is ignored and count is skipped.
        :param str cursor: Cursor for current page of results. To retrieve first page with cursor pagination you need to pass this parameter with empty value. For next pages the value must be taken from response (<code>nextCursor</code> property).
        :param str relation_type_id: The ID of the type of relations to search for.
        :param str source_id: The ID of the source of relations to search for.
        :param str target_id: The ID of the target of relations to search for.
        :param str source_target_logical_operator: The logical operator determining how to combine the source and target criteria: AND or OR.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RelationPagedResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'offset',
            'limit',
            'count_limit',
            'cursor',
            'relation_type_id',
            'source_id',
            'target_id',
            'source_target_logical_operator'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_relations" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'count_limit' in local_var_params and local_var_params['count_limit'] is not None:  # noqa: E501
            query_params.append(('countLimit', local_var_params['count_limit']))  # noqa: E501
        if 'cursor' in local_var_params and local_var_params['cursor'] is not None:  # noqa: E501
            query_params.append(('cursor', local_var_params['cursor']))  # noqa: E501
        if 'relation_type_id' in local_var_params and local_var_params['relation_type_id'] is not None:  # noqa: E501
            query_params.append(('relationTypeId', local_var_params['relation_type_id']))  # noqa: E501
        if 'source_id' in local_var_params and local_var_params['source_id'] is not None:  # noqa: E501
            query_params.append(('sourceId', local_var_params['source_id']))  # noqa: E501
        if 'target_id' in local_var_params and local_var_params['target_id'] is not None:  # noqa: E501
            query_params.append(('targetId', local_var_params['target_id']))  # noqa: E501
        if 'source_target_logical_operator' in local_var_params and local_var_params['source_target_logical_operator'] is not None:  # noqa: E501
            query_params.append(('sourceTargetLogicalOperator', local_var_params['source_target_logical_operator']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relations', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RelationPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_relation(self, relation_id, **kwargs):  # noqa: E501
        """Returns a relation identified by given id.  # noqa: E501

        Returns a relation identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_relation(relation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str relation_id: the ID of the relation (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RelationImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_relation_with_http_info(relation_id, **kwargs)  # noqa: E501

    def get_relation_with_http_info(self, relation_id, **kwargs):  # noqa: E501
        """Returns a relation identified by given id.  # noqa: E501

        Returns a relation identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_relation_with_http_info(relation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str relation_id: the ID of the relation (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RelationImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'relation_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_relation" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'relation_id' is set
        if self.api_client.client_side_validation and ('relation_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['relation_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `relation_id` when calling `get_relation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'relation_id' in local_var_params:
            path_params['relationId'] = local_var_params['relation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relations/{relationId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RelationImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_relation(self, relation_id, **kwargs):  # noqa: E501
        """Removes a relation identified by given id.  # noqa: E501

        Removes a relation identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_relation(relation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str relation_id: the ID of the relation to remove (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_relation_with_http_info(relation_id, **kwargs)  # noqa: E501

    def remove_relation_with_http_info(self, relation_id, **kwargs):  # noqa: E501
        """Removes a relation identified by given id.  # noqa: E501

        Removes a relation identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_relation_with_http_info(relation_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str relation_id: the ID of the relation to remove (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'relation_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_relation" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'relation_id' is set
        if self.api_client.client_side_validation and ('relation_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['relation_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `relation_id` when calling `remove_relation`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'relation_id' in local_var_params:
            path_params['relationId'] = local_var_params['relation_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relations/{relationId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_relations(self, **kwargs):  # noqa: E501
        """Removes multiple relations.  # noqa: E501

        Removes multiple relations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_relations(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: the IDs of the relations to be removed
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_relations_with_http_info(**kwargs)  # noqa: E501

    def remove_relations_with_http_info(self, **kwargs):  # noqa: E501
        """Removes multiple relations.  # noqa: E501

        Removes multiple relations.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_relations_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body: the IDs of the relations to be removed
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_relations" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/relations/bulk', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class WorkflowTasksApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cancel_workflow_task(self, workflow_task_id, **kwargs):  # noqa: E501
        """Cancel workflow task.  # noqa: E501

        Cancels the workflow task with the specified ID with a reason. If the given workflow is a subprocess, this method makes sure everything is cancelled from the root process instance. If the given task is not found, this method will assume it already was cancelled without throwing any error.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_workflow_task(workflow_task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_task_id: The ID of the workflow task. (required)
        :param str body: The reason for the cancellation of the workflow task.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.cancel_workflow_task_with_http_info(workflow_task_id, **kwargs)  # noqa: E501

    def cancel_workflow_task_with_http_info(self, workflow_task_id, **kwargs):  # noqa: E501
        """Cancel workflow task.  # noqa: E501

        Cancels the workflow task with the specified ID with a reason. If the given workflow is a subprocess, this method makes sure everything is cancelled from the root process instance. If the given task is not found, this method will assume it already was cancelled without throwing any error.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_workflow_task_with_http_info(workflow_task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_task_id: The ID of the workflow task. (required)
        :param str body: The reason for the cancellation of the workflow task.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_task_id',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_workflow_task" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_task_id' is set
        if self.api_client.client_side_validation and ('workflow_task_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_task_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_task_id` when calling `cancel_workflow_task`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_task_id' in local_var_params:
            path_params['workflowTaskId'] = local_var_params['workflow_task_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowTasks/{workflowTaskId}/canceled', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def complete_workflow_tasks(self, **kwargs):  # noqa: E501
        """Complete workflow tasks.  # noqa: E501

        Completes tasks based on the provided request and returns the following tasks, if the same user is assigned to them.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.complete_workflow_tasks(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CompleteWorkflowTasksRequest complete_workflow_tasks_request: Request to complete the workflow tasks.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[WorkflowTask]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.complete_workflow_tasks_with_http_info(**kwargs)  # noqa: E501

    def complete_workflow_tasks_with_http_info(self, **kwargs):  # noqa: E501
        """Complete workflow tasks.  # noqa: E501

        Completes tasks based on the provided request and returns the following tasks, if the same user is assigned to them.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.complete_workflow_tasks_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CompleteWorkflowTasksRequest complete_workflow_tasks_request: Request to complete the workflow tasks.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[WorkflowTask], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'complete_workflow_tasks_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method complete_workflow_tasks" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'complete_workflow_tasks_request' in local_var_params:
            body_params = local_var_params['complete_workflow_tasks_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowTasks/completed', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[WorkflowTask]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_workflow_tasks(self, **kwargs):  # noqa: E501
        """Find workflow tasks.  # noqa: E501

        Returns the workflow tasks matching given search criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_workflow_tasks(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str business_item_id: The ID of the business item
        :param str business_item_type: The type of the business item
        :param str workflow_task_user_relation: The type of relation between user and searched tasks. This could be either set to search for all the tasks the user is permitted to view or just those assigned to the user.
        :param str business_item_name: The part of the name of the business item.
        :param str description: The part of the task description.
        :param str user_id: The ID of the user for which the tasks need to be returned. If empty, the current logged in user will be used
        :param int create_date: The creation date of the task. It is the timestamp (in UTC time standard)
        :param int due_date: The due date of the task. It is the timestamp (in UTC time standard)
        :param str title: The title/name of the task.
        :param str type: The task type.
        :param str sort_field: The field on which the results are sorted. On due date by default.
        :param str sort_order: The sorting order.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WorkflowTaskPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_workflow_tasks_with_http_info(**kwargs)  # noqa: E501

    def find_workflow_tasks_with_http_info(self, **kwargs):  # noqa: E501
        """Find workflow tasks.  # noqa: E501

        Returns the workflow tasks matching given search criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_workflow_tasks_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str business_item_id: The ID of the business item
        :param str business_item_type: The type of the business item
        :param str workflow_task_user_relation: The type of relation between user and searched tasks. This could be either set to search for all the tasks the user is permitted to view or just those assigned to the user.
        :param str business_item_name: The part of the name of the business item.
        :param str description: The part of the task description.
        :param str user_id: The ID of the user for which the tasks need to be returned. If empty, the current logged in user will be used
        :param int create_date: The creation date of the task. It is the timestamp (in UTC time standard)
        :param int due_date: The due date of the task. It is the timestamp (in UTC time standard)
        :param str title: The title/name of the task.
        :param str type: The task type.
        :param str sort_field: The field on which the results are sorted. On due date by default.
        :param str sort_order: The sorting order.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WorkflowTaskPagedResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'offset',
            'limit',
            'count_limit',
            'business_item_id',
            'business_item_type',
            'workflow_task_user_relation',
            'business_item_name',
            'description',
            'user_id',
            'create_date',
            'due_date',
            'title',
            'type',
            'sort_field',
            'sort_order'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_workflow_tasks" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'count_limit' in local_var_params and local_var_params['count_limit'] is not None:  # noqa: E501
            query_params.append(('countLimit', local_var_params['count_limit']))  # noqa: E501
        if 'business_item_id' in local_var_params and local_var_params['business_item_id'] is not None:  # noqa: E501
            query_params.append(('businessItemId', local_var_params['business_item_id']))  # noqa: E501
        if 'business_item_type' in local_var_params and local_var_params['business_item_type'] is not None:  # noqa: E501
            query_params.append(('businessItemType', local_var_params['business_item_type']))  # noqa: E501
        if 'workflow_task_user_relation' in local_var_params and local_var_params['workflow_task_user_relation'] is not None:  # noqa: E501
            query_params.append(('workflowTaskUserRelation', local_var_params['workflow_task_user_relation']))  # noqa: E501
        if 'business_item_name' in local_var_params and local_var_params['business_item_name'] is not None:  # noqa: E501
            query_params.append(('businessItemName', local_var_params['business_item_name']))  # noqa: E501
        if 'description' in local_var_params and local_var_params['description'] is not None:  # noqa: E501
            query_params.append(('description', local_var_params['description']))  # noqa: E501
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('userId', local_var_params['user_id']))  # noqa: E501
        if 'create_date' in local_var_params and local_var_params['create_date'] is not None:  # noqa: E501
            query_params.append(('createDate', local_var_params['create_date']))  # noqa: E501
        if 'due_date' in local_var_params and local_var_params['due_date'] is not None:  # noqa: E501
            query_params.append(('dueDate', local_var_params['due_date']))  # noqa: E501
        if 'title' in local_var_params and local_var_params['title'] is not None:  # noqa: E501
            query_params.append(('title', local_var_params['title']))  # noqa: E501
        if 'type' in local_var_params and local_var_params['type'] is not None:  # noqa: E501
            query_params.append(('type', local_var_params['type']))  # noqa: E501
        if 'sort_field' in local_var_params and local_var_params['sort_field'] is not None:  # noqa: E501
            query_params.append(('sortField', local_var_params['sort_field']))  # noqa: E501
        if 'sort_order' in local_var_params and local_var_params['sort_order'] is not None:  # noqa: E501
            query_params.append(('sortOrder', local_var_params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowTasks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WorkflowTaskPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_task_form_data(self, workflow_task_id, **kwargs):  # noqa: E501
        """Get task form data.  # noqa: E501

        Returns the task form data of the workflow task with the specified ID and form property type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_task_form_data(workflow_task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_task_id: Workflow task ID. (required)
        :param str form_property_type: Form property type.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TaskFormData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_task_form_data_with_http_info(workflow_task_id, **kwargs)  # noqa: E501

    def get_task_form_data_with_http_info(self, workflow_task_id, **kwargs):  # noqa: E501
        """Get task form data.  # noqa: E501

        Returns the task form data of the workflow task with the specified ID and form property type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_task_form_data_with_http_info(workflow_task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_task_id: Workflow task ID. (required)
        :param str form_property_type: Form property type.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TaskFormData, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_task_id',
            'form_property_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_task_form_data" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_task_id' is set
        if self.api_client.client_side_validation and ('workflow_task_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_task_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_task_id` when calling `get_task_form_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_task_id' in local_var_params:
            path_params['workflowTaskId'] = local_var_params['workflow_task_id']  # noqa: E501

        query_params = []
        if 'form_property_type' in local_var_params and local_var_params['form_property_type'] is not None:  # noqa: E501
            query_params.append(('formPropertyType', local_var_params['form_property_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowTasks/{workflowTaskId}/taskFormData', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TaskFormData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workflow_task(self, workflow_task_id, **kwargs):  # noqa: E501
        """Get workflow task.  # noqa: E501

        Returns the workflow task with the specified ID. A task will only be returned when the user has the correct permission to view it.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_task(workflow_task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_task_id: The ID of the workflow task to return. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WorkflowTask
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_workflow_task_with_http_info(workflow_task_id, **kwargs)  # noqa: E501

    def get_workflow_task_with_http_info(self, workflow_task_id, **kwargs):  # noqa: E501
        """Get workflow task.  # noqa: E501

        Returns the workflow task with the specified ID. A task will only be returned when the user has the correct permission to view it.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workflow_task_with_http_info(workflow_task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_task_id: The ID of the workflow task to return. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WorkflowTask, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_task_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workflow_task" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_task_id' is set
        if self.api_client.client_side_validation and ('workflow_task_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_task_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_task_id` when calling `get_workflow_task`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_task_id' in local_var_params:
            path_params['workflowTaskId'] = local_var_params['workflow_task_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowTasks/{workflowTaskId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WorkflowTask',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reassign_task(self, workflow_task_id, **kwargs):  # noqa: E501
        """Reassign task.  # noqa: E501

        Reassigns the task with the specified ID to one or more users, groups or roles. Caller needs to provide at least one of the value list for users, groups or roles. If roles are provided then the same number of communities needs to be provided also.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reassign_task(workflow_task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_task_id: The ID of the workflow task. (required)
        :param list[str] users: The user IDs to reassign to.
        :param list[str] groups: The group IDs to reassign to.
        :param list[str] roles: The role IDs to reassign to.
        :param list[str] communities: The Community IDs of the specified roles to reassign to.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.reassign_task_with_http_info(workflow_task_id, **kwargs)  # noqa: E501

    def reassign_task_with_http_info(self, workflow_task_id, **kwargs):  # noqa: E501
        """Reassign task.  # noqa: E501

        Reassigns the task with the specified ID to one or more users, groups or roles. Caller needs to provide at least one of the value list for users, groups or roles. If roles are provided then the same number of communities needs to be provided also.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reassign_task_with_http_info(workflow_task_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str workflow_task_id: The ID of the workflow task. (required)
        :param list[str] users: The user IDs to reassign to.
        :param list[str] groups: The group IDs to reassign to.
        :param list[str] roles: The role IDs to reassign to.
        :param list[str] communities: The Community IDs of the specified roles to reassign to.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'workflow_task_id',
            'users',
            'groups',
            'roles',
            'communities'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reassign_task" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'workflow_task_id' is set
        if self.api_client.client_side_validation and ('workflow_task_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['workflow_task_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `workflow_task_id` when calling `reassign_task`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'workflow_task_id' in local_var_params:
            path_params['workflowTaskId'] = local_var_params['workflow_task_id']  # noqa: E501

        query_params = []
        if 'users' in local_var_params and local_var_params['users'] is not None:  # noqa: E501
            query_params.append(('users', local_var_params['users']))  # noqa: E501
            collection_formats['users'] = 'multi'  # noqa: E501
        if 'groups' in local_var_params and local_var_params['groups'] is not None:  # noqa: E501
            query_params.append(('groups', local_var_params['groups']))  # noqa: E501
            collection_formats['groups'] = 'multi'  # noqa: E501
        if 'roles' in local_var_params and local_var_params['roles'] is not None:  # noqa: E501
            query_params.append(('roles', local_var_params['roles']))  # noqa: E501
            collection_formats['roles'] = 'multi'  # noqa: E501
        if 'communities' in local_var_params and local_var_params['communities'] is not None:  # noqa: E501
            query_params.append(('communities', local_var_params['communities']))  # noqa: E501
            collection_formats['communities'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/workflowTasks/{workflowTaskId}/reassign', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class ApplicationVersionImpl(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'major': 'int',
        'minor': 'int',
        'full_version': 'str',
        'display_version': 'str'
    }

    attribute_map = {
        'major': 'major',
        'minor': 'minor',
        'full_version': 'fullVersion',
        'display_version': 'displayVersion'
    }

    def __init__(self, major=None, minor=None, full_version=None, display_version=None, local_vars_configuration=None):  # noqa: E501
        """ApplicationVersionImpl - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._major = None
        self._minor = None
        self._full_version = None
        self._display_version = None
        self.discriminator = None

        if major is not None:
            self.major = major
        if minor is not None:
            self.minor = minor
        if full_version is not None:
            self.full_version = full_version
        if display_version is not None:
            self.display_version = display_version

    @property
    def major(self):
        """Gets the major of this ApplicationVersionImpl.  # noqa: E501

        The major version number of the application version. This version number is increased with the major changes and releases of the application  # noqa: E501

        :return: The major of this ApplicationVersionImpl.  # noqa: E501
        :rtype: int
        """
        return self._major

    @major.setter
    def major(self, major):
        """Sets the major of this ApplicationVersionImpl.

        The major version number of the application version. This version number is increased with the major changes and releases of the application  # noqa: E501

        :param major: The major of this ApplicationVersionImpl.  # noqa: E501
        :type: int
        """

        self._major = major

    @property
    def minor(self):
        """Gets the minor of this ApplicationVersionImpl.  # noqa: E501

        The minor version number of the application version. This version number is increased whenever new features are added in given release  # noqa: E501

        :return: The minor of this ApplicationVersionImpl.  # noqa: E501
        :rtype: int
        """
        return self._minor

    @minor.setter
    def minor(self, minor):
        """Sets the minor of this ApplicationVersionImpl.

        The minor version number of the application version. This version number is increased whenever new features are added in given release  # noqa: E501

        :param minor: The minor of this ApplicationVersionImpl.  # noqa: E501
        :type: int
        """

        self._minor = minor

    @property
    def full_version(self):
        """Gets the full_version of this ApplicationVersionImpl.  # noqa: E501

        The full version of the application.  # noqa: E501

        :return: The full_version of this ApplicationVersionImpl.  # noqa: E501
        :rtype: str
        """
        return self._full_version

    @full_version.setter
    def full_version(self, full_version):
        """Sets the full_version of this ApplicationVersionImpl.

        The full version of the application.  # noqa: E501

        :param full_version: The full_version of this ApplicationVersionImpl.  # noqa: E501
        :type: str
        """

        self._full_version = full_version

    @property
    def display_version(self):
        """Gets the display_version of this ApplicationVersionImpl.  # noqa: E501

        The display version of the application. This is the version to be displayed to the customer and can be different from the actual internal version.  # noqa: E501

        :return: The display_version of this ApplicationVersionImpl.  # noqa: E501
        :rtype: str
        """
        return self._display_version

    @display_version.setter
    def display_version(self, display_version):
        """Sets the display_version of this ApplicationVersionImpl.

        The display version of the application. This is the version to be displayed to the customer and can be different from the actual internal version.  # noqa: E501

        :param display_version: The display_version of this ApplicationVersionImpl.  # noqa: E501
        :type: str
        """

        self._display_version = display_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationVersionImpl):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApplicationVersionImpl):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.paged_response_comment import PagedResponseComment  # noqa: E501
from collibra_core.rest import ApiException

class TestPagedResponseComment(unittest.TestCase):
    """PagedResponseComment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PagedResponseComment
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.paged_response_comment.PagedResponseComment()  # noqa: E501
        if include_optional :
            return PagedResponseComment(
                total = 1000, 
                offset = 10, 
                limit = 100, 
                results = [
                    collibra_core.models.comment.Comment(
                        id = '0', 
                        created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                        created_on = 1475503010320, 
                        last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                        last_modified_on = 1476703764163, 
                        system = True, 
                        resource_type = 'View', 
                        content = '0', 
                        mentioned_users = [
                            collibra_core.models.user.User(
                                id = '0', 
                                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                created_on = 1475503010320, 
                                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                last_modified_on = 1476703764163, 
                                system = True, 
                                resource_type = 'View', 
                                user_name = '0', 
                                first_name = '0', 
                                last_name = '0', 
                                email_address = '0', 
                                gender = 'MALE', 
                                language = '0', 
                                additional_email_addresses = [
                                    collibra_core.models.email.Email(
                                        id = '0', 
                                        created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                        created_on = 1475503010320, 
                                        last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                        last_modified_on = 1476703764163, 
                                        system = True, 
                                        resource_type = 'View', 
                                        email_address = '0', )
                                    ], 
                                phone_numbers = [
                                    collibra_core.models.phone_number.PhoneNumber(
                                        id = '0', 
                                        created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                        created_on = 1475503010320, 
                                        last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                        last_modified_on = 1476703764163, 
                                        system = True, 
                                        resource_type = 'View', 
                                        type = 'FAX', 
                                        phone_number = '0', )
                                    ], 
                                instant_messaging_accounts = [
                                    collibra_core.models.instant_messaging_account.InstantMessagingAccount(
                                        id = '0', 
                                        created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                        created_on = 1475503010320, 
                                        last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                        last_modified_on = 1476703764163, 
                                        system = True, 
                                        resource_type = 'View', 
                                        account = '0', 
                                        type = 'AOL', )
                                    ], 
                                websites = [
                                    collibra_core.models.website.Website(
                                        id = '0', 
                                        created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                        created_on = 1475503010320, 
                                        last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                        last_modified_on = 1476703764163, 
                                        system = True, 
                                        resource_type = 'View', 
                                        url = '0', 
                                        type = 'FACEBOOK', )
                                    ], 
                                addresses = [
                                    collibra_core.models.address.Address(
                                        id = '0', 
                                        created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                        created_on = 1475503010320, 
                                        last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                        last_modified_on = 1476703764163, 
                                        system = True, 
                                        resource_type = 'View', 
                                        city = '0', 
                                        street = '0', 
                                        number = '0', 
                                        state = '0', 
                                        country = '0', 
                                        postal_code = '0', 
                                        type = 'HOME', )
                                    ], 
                                activated = True, 
                                enabled = True, 
                                ldap_user = True, 
                                user_source = 'INTERNAL', 
                                guest_user = True, 
                                api_user = True, 
                                license_type = 'CONSUMER', )
                            ], 
                        base_resource = collibra_core.models.resource_reference.ResourceReference(
                            id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                            resource_type = 'Community', ), 
                        parent = collibra_core.models.resource_reference.ResourceReference(
                            id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                            resource_type = 'Community', ), )
                    ]
            )
        else :
            return PagedResponseComment(
        )

    def testPagedResponseComment(self):
        """Test PagedResponseComment"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.paged_response_workflow_definition import PagedResponseWorkflowDefinition  # noqa: E501
from collibra_core.rest import ApiException

class TestPagedResponseWorkflowDefinition(unittest.TestCase):
    """PagedResponseWorkflowDefinition unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PagedResponseWorkflowDefinition
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.paged_response_workflow_definition.PagedResponseWorkflowDefinition()  # noqa: E501
        if include_optional :
            return PagedResponseWorkflowDefinition(
                total = 1000, 
                offset = 10, 
                limit = 100, 
                results = [
                    collibra_core.models.workflow_definition_impl.WorkflowDefinitionImpl(
                        id = '0', 
                        created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                        created_on = 1475503010320, 
                        last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                        last_modified_on = 1476703764163, 
                        system = True, 
                        resource_type = 'View', 
                        name = 'Test name', 
                        description = 'Sample descripion of the resource.', 
                        process_id = '0', 
                        start_label = '0', 
                        form_required = True, 
                        start_form_key_available = True, 
                        start_form_json_model_available = True, 
                        enabled = True, 
                        domain_assignment_rules = [
                            collibra_core.models.asset_assignment_rule_impl.AssetAssignmentRuleImpl(
                                id = '0', 
                                asset_type = collibra_core.models.named_resource_reference_impl.NamedResourceReferenceImpl(
                                    id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                                    resource_type = 'Community', 
                                    name = '0', ), 
                                domain = collibra_core.models.named_resource_reference_impl.NamedResourceReferenceImpl(
                                    id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                                    resource_type = 'Community', 
                                    name = '0', ), 
                                community = collibra_core.models.named_resource_reference_impl.NamedResourceReferenceImpl(
                                    id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                                    resource_type = 'Community', 
                                    name = '0', ), 
                                status = collibra_core.models.named_resource_reference_impl.NamedResourceReferenceImpl(
                                    id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                                    resource_type = 'Community', 
                                    name = '0', ), )
                            ], 
                        asset_assignment_rules = [
                            collibra_core.models.asset_assignment_rule_impl.AssetAssignmentRuleImpl(
                                id = '0', )
                            ], 
                        business_item_resource_type = 'ASSET', 
                        exclusivity = 'RESOURCE_EXCLUSIVITY', 
                        guest_user_accessible = True, 
                        registered_user_accessible = True, 
                        candidate_user_check_enabled = True, 
                        global_create = True, 
                        start_events = [
                            'ASSET_ADDED'
                            ], 
                        configuration_variables = {
                            'key' : '0'
                            }, 
                        start_roles = [
                            collibra_core.models.role_impl.RoleImpl(
                                id = '0', 
                                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                created_on = 1475503010320, 
                                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                last_modified_on = 1476703764163, 
                                system = True, 
                                resource_type = 'View', 
                                name = 'Test name', 
                                description = 'Sample descripion of the resource.', 
                                permissions = [
                                    'EDGE'
                                    ], 
                                global = True, )
                            ], 
                        stop_roles = [
                            collibra_core.models.role_impl.RoleImpl(
                                id = '0', 
                                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                created_on = 1475503010320, 
                                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                last_modified_on = 1476703764163, 
                                system = True, 
                                resource_type = 'View', 
                                name = 'Test name', 
                                description = 'Sample descripion of the resource.', 
                                global = True, )
                            ], 
                        reassign_roles = [
                            collibra_core.models.role_impl.RoleImpl(
                                id = '0', 
                                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                created_on = 1475503010320, 
                                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                last_modified_on = 1476703764163, 
                                system = True, 
                                resource_type = 'View', 
                                name = 'Test name', 
                                description = 'Sample descripion of the resource.', 
                                global = True, )
                            ], )
                    ]
            )
        else :
            return PagedResponseWorkflowDefinition(
        )

    def testPagedResponseWorkflowDefinition(self):
        """Test PagedResponseWorkflowDefinition"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
